X-Git-Url: http://cvs.zerfleddert.de/cgi-bin/gitweb.cgi/proxmark3-svn/blobdiff_plain/e3ac0d70956f5b5fee633f7cbf4b3b8616e4f06c..81f9cbb188287393626ce7fa24b47633b2fd440b:/tools/mkversion.pl

diff --git a/tools/mkversion.pl b/tools/mkversion.pl
index de394a85..f726640e 100644
--- a/tools/mkversion.pl
+++ b/tools/mkversion.pl
@@ -5,20 +5,28 @@
 # -- Henryk Plötz <henryk@ploetzli.ch> 2009-09-28
 # Modified april 2014 because of the move to github. 
 # --- Martin Holst Swende <martin@swende.se>
+# Modified january 2016 to work with Travis-CI
+# --- iceman <iceman@iuse.se>
 
-
-# Clear environment locale so that svn will not use localized strings
+# Clear environment locale so that git will not use localized strings
 $ENV{'LC_ALL'} = "C";
 $ENV{'LANG'} = "C";
 
+my $githistory = `git fetch --all`;
 my $gitversion = `git describe --dirty`;
 my $gitbranch = `git rev-parse --abbrev-ref HEAD`;
-my $clean = 2;
-my @compiletime = gmtime();
+my $clean = $gitversion =~ '-dirty' ? 0 : 1;
+my @compiletime = localtime();
+
+my $fullgitinfo = 'iceman';
 
-my $fullgitinfo= $gitbranch . '/'.$gitversion;
+if ( defined $gitbranch and defined $gitversion ) {
+	$fullgitinfo =  $fullgitinfo.'/'. $gitbranch . '/' . $gitversion;
+} else {
+	$fullgitinfo =  $fullgitinfo.'/master/release-build (no_git)';
+}
 
-$fullgitinfo=~ s/(\s)//g;
+$fullgitinfo =~ s/(\s)//g;
 
 # Crop so it fits within 50 characters
 $fullgitinfo =~ s/.{50}\K.*//s;